"""migrate from experiments to jobs

Revision ID: 96f304f85ee5
Revises: 379008363046
Create Date: 2021-01-18 16:17:59.564514

"""
import sqlalchemy as sa
from alembic import op
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = "96f304f85ee5"
down_revision = "379008363046"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "jobs",
        sa.Column("job_uuid", sa.String(length=36), nullable=False),
        sa.Column("project_uuid", sa.String(length=36), nullable=True),
        sa.Column("pipeline_uuid", sa.String(length=36), nullable=True),
        sa.Column("total_number_of_pipeline_runs", sa.Integer(), nullable=False),
        sa.Column("scheduled_start", sa.DateTime(), nullable=False),
        sa.Column(
            "completed_pipeline_runs",
            sa.Integer(),
            server_default=sa.text("0"),
            nullable=True,
        ),
        sa.PrimaryKeyConstraint("job_uuid", name=op.f("pk_jobs")),
    )
    op.add_column(
        "pipeline_runs", sa.Column("job_uuid", sa.String(length=36), nullable=True)
    )
    op.create_foreign_key(
        op.f("fk_pipeline_runs_job_uuid_jobs"),
        "pipeline_runs",
        "jobs",
        ["job_uuid"],
        ["job_uuid"],
        ondelete="CASCADE",
    )

    op.drop_constraint(
        "fk_pipeline_runs_experiment_uuid_experiments",
        "pipeline_runs",
        type_="foreignkey",
    )
    op.drop_column("pipeline_runs", "experiment_uuid")
    op.drop_table("experiments")
    # ### end Alembic commands ###


def downgrade():
    # Note: downgrade has not been checked for correctness.

    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "pipeline_runs",
        sa.Column(
            "experiment_uuid", sa.VARCHAR(length=36), autoincrement=False, nullable=True
        ),
    )
    op.drop_constraint(
        op.f("fk_pipeline_runs_job_uuid_jobs"), "pipeline_runs", type_="foreignkey"
    )
    op.create_foreign_key(
        "fk_pipeline_runs_experiment_uuid_experiments",
        "pipeline_runs",
        "experiments",
        ["experiment_uuid"],
        ["experiment_uuid"],
        ondelete="CASCADE",
    )
    op.drop_column("pipeline_runs", "job_uuid")
    op.create_table(
        "experiments",
        sa.Column(
            "experiment_uuid",
            sa.VARCHAR(length=36),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "project_uuid", sa.VARCHAR(length=36), autoincrement=False, nullable=True
        ),
        sa.Column(
            "pipeline_uuid", sa.VARCHAR(length=36), autoincrement=False, nullable=True
        ),
        sa.Column(
            "total_number_of_pipeline_runs",
            sa.INTEGER(),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "scheduled_start",
            postgresql.TIMESTAMP(),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "completed_pipeline_runs",
            sa.INTEGER(),
            server_default=sa.text("0"),
            autoincrement=False,
            nullable=True,
        ),
        sa.PrimaryKeyConstraint("experiment_uuid", name="pk_experiments"),
    )
    op.drop_table("jobs")
    # ### end Alembic commands ###
